@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from fastcodedog.context.contextbase import ContextBase
 from fastcodedog.context.crud.column import Column
+from fastcodedog.context.crud.default_value import DefaultValue
 from fastcodedog.context.crud.join_relationship import JoinRelationship
 from fastcodedog.context.crud.query import Query
 
@@ -23,6 +24,8 @@ class Crud(ContextBase):
         self._types['join_relationships'] = JoinRelationship
         self.queries = {}
         self._types['queries'] = Query
+        self.default_values = {}
+        self._types['default_values'] = DefaultValue
 
     def load(self, json):
         for k, v in json.items():
