@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from fastcodedog.context.common.import_ import Import_
 from fastcodedog.context.contextbase import ContextBase
 
 
@@ -15,5 +14,5 @@ class ComputedProperty(ContextBase):
         self.model_name = ''
         self.nullable = True
         self.script = ''
-        self.import_ = None
-        self._types['import_'] = Import_
+        self.import_ = []
+        self._types['import_'] = str
