@@ -7,6 +7,7 @@ class Relationship(ContextBase):
         super().__init__()
         self.name = ''  # 关系名
         self.original_name = ''  # 原始关系名，为转为复数。有时候需要非复数原始版本
+        self.comment = ''
         self.back_populates_module = ''  # back_populates的模块
         self.back_populates_model = ''  # back_populates的model
         self.foreign_keys = ''  # 关联使用的外键
@@ -16,6 +17,7 @@ class Relationship(ContextBase):
         self.cascade = ''
         self.back_populates = ''  # back_populates变量名
         self.no_back_populates = False  # 不生成back_populates
+        self.viewonly = False   # 只读
         self.disabled = False  # 禁用。和上面的no_backup是一对
         self.from_join_table = False  # 是否是join_table
         self.is_list = False  # 是否是列表
