@@ -18,4 +18,7 @@ class Init(File):
         for module, models in ctx_instance.models.items():
             for model in models.values():
                 required_import.add(model.name, LocationFinder.get_package(model.name, 'model', module))
+        # 支持自定义listener
+        for listen in ctx_instance.listens:
+            required_import.add(import_=listen.import_, from_=listen.from_, as_=listen.alias)
         return required_import
