@@ -16,12 +16,15 @@ class Relationship(Variable):
         self.cascade = context.cascade
         self.back_populates = context.back_populates  # back_populates变量名
         self.no_back_populates = context.no_back_populates  # 不生成back_populates
+        self.viewonly = context.viewonly                    #
         # self.disabled = context.disabled                      # 禁用的时候，直接不创建relationship
         self.primaryjoin = context.primaryjoin  # 主连接条件
         self.secondaryjoin = context.secondaryjoin
 
         self.value = self.get_value()
         self.comment = f"no back populates {self.back_populates}" if self.no_back_populates else ''
+        if context.comment:
+            self.comment = context.comment
         # self.possible_imports = {
         #     'relationship': Import('sqlalchemy.orm', 'relationship')
         # }
@@ -32,13 +35,15 @@ class Relationship(Variable):
     def get_value(self):
         relationship_params = [f"'{self.back_populates_model}'"]
         if self.foreign_keys:
-            relationship_params.append(f"foreign_keys={self.foreign_keys}")
+            relationship_params.append(f"foreign_keys={self.foreign_keys}" if self.foreign_keys.find('.') == -1 else f"foreign_keys='{self.foreign_keys}'")
         if self.secondary:
             relationship_params.append(f"secondary='{self.secondary}'")
         if self.remote_side:
             relationship_params.append(f"remote_side={self.remote_side}")
         if self.primaryjoin:
             relationship_params.append(f"primaryjoin='{self.primaryjoin}'")
+        if self.viewonly:
+            relationship_params.append(f"viewonly=True")
         if self.secondaryjoin:
             relationship_params.append(f"secondaryjoin='{self.secondaryjoin}'")
         if self.cascade:
