@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import os, shutil
 from fastcodedog.context.context import ctx_instance
+from fastcodedog.prepare.pdm_to_model.after.additional_relationships import add_relationships
 from fastcodedog.prepare.pdm_to_model.after.computed_properties import add_computed_properties
 from fastcodedog.prepare.pdm_to_model.after.additional_methods import add_additional_methods
 from fastcodedog.prepare.pdm_to_model.after.disable_relationships import disable_relationships
@@ -24,6 +25,7 @@ def prepare_model(pre_process_scripts):
 
     pdm.to_model()
     # 对导出后的model做些批量操作
+    add_relationships(ctx_instance.source_directory.model, pre_process_scripts['additional_relationships'])
     disable_relationships(ctx_instance.source_directory.model, pre_process_scripts['disable_relationships'])
     # rename_specified_class_names(ctx_instance.source_directory.model, pre_process_scripts['specified_class_names'])
     add_computed_properties(ctx_instance.source_directory.model, pre_process_scripts['computed_properties'])
